@@ -3,10 +3,10 @@ function (phy1, phy2, method = "prop") {
 	phy1 <- unroot(phy1)
 	phy2 <- unroot(phy2)
 	nphy1 <- length(phy1$tip.label)
-	bp1 <- .Call("bipartition", phy1$edge, nphy1, phy1$Nnode, PACKAGE = "ape")
+	bp1 <- prop.part(phy1)
 	bp1 <- lapply(bp1, function(xx) sort(phy1$tip.label[xx]))
 	nphy2 <- length(phy2$tip.label)
-	bp2.tmp <- .Call("bipartition", phy2$edge, nphy2, phy2$Nnode, PACKAGE = "ape")
+	bp2.tmp <- prop.part(phy2)
 	bp2 <- lapply(bp2.tmp, function(xx) sort(phy2$tip.label[xx]))
 	bp2.comp <- lapply(bp2.tmp, function(xx) setdiff(1:nphy2, xx))
 	bp2.comp <- lapply(bp2.comp, function(xx) sort(phy2$tip.label[xx]))
